Reference File
==============
The ``extract_1d`` step uses an EXTRACT1D reference file and an APCORR reference file.

.. include:: ../references_general/extract1d_reffile.inc
.. include:: ../references_general/apcorr_reffile.inc
